# flake8: noqa

"""
    Open:Risk API

    Service to calculate parametric linear risk statistics and generate risk model asset identifier mappings.  # noqa: E501

    The version of the OpenAPI document: 1.26.0
    Contact: api@factset.com
    Generated by: https://openapi-generator.tech
"""


__version__ = "4.0.2"

# import ApiClient
from fds.sdk.OpenRisk.api_client import ApiClient

# import Configuration
from fds.sdk.OpenRisk.configuration import Configuration

# import exceptions
from fds.sdk.OpenRisk.exceptions import OpenApiException
from fds.sdk.OpenRisk.exceptions import ApiAttributeError
from fds.sdk.OpenRisk.exceptions import ApiTypeError
from fds.sdk.OpenRisk.exceptions import ApiValueError
from fds.sdk.OpenRisk.exceptions import ApiKeyError
from fds.sdk.OpenRisk.exceptions import ApiException



"""
    Open:Risk API

    Service to calculate parametric linear risk statistics and generate risk model asset identifier mappings.  # noqa: E501

    The version of the OpenAPI document: 1.26.0
    Contact: api@factset.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401
from multiprocessing.pool import ApplyResult
import typing

from fds.sdk.OpenRisk.api_client import ApiClient, Endpoint as _Endpoint
from fds.sdk.OpenRisk.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from fds.sdk.OpenRisk.exceptions import ApiException
from fds.sdk.OpenRisk.model.calculate_from_holdings_request_body import CalculateFromHoldingsRequestBody
from fds.sdk.OpenRisk.model.error_response import ErrorResponse
from fds.sdk.OpenRisk.model.generate_id_mapping_request_body import GenerateIdMappingRequestBody
from fds.sdk.OpenRisk.model.inline_response2003 import InlineResponse2003
from fds.sdk.OpenRisk.model.inline_response2004 import InlineResponse2004





class OperationsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self.calculate_from_holdings_endpoint = _Endpoint(
            settings={
                'response_type': (
                  { 200: (InlineResponse2003,), 400: (ErrorResponse,), 401: (str,), 403: (ErrorResponse,), 404: (ErrorResponse,), 500: (ErrorResponse,),  },
                  None
                ),
                'auth': [
                    'FactSetApiKey',
                    'FactSetOAuth2'
                ],
                'endpoint_path': '/calculate/from-holdings',
                'operation_id': 'calculate_from_holdings',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'calculate_from_holdings_request_body',
                ],
                'required': [
                    'calculate_from_holdings_request_body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'calculate_from_holdings_request_body':
                        (CalculateFromHoldingsRequestBody,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'calculate_from_holdings_request_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json',
                    'text/plain'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

        self.generate_id_mapping_endpoint = _Endpoint(
            settings={
                'response_type': (
                  { 200: (InlineResponse2004,), 400: (ErrorResponse,), 401: (str,), 403: (ErrorResponse,), 404: (ErrorResponse,), 500: (ErrorResponse,),  },
                  None
                ),
                'auth': [
                    'FactSetApiKey',
                    'FactSetOAuth2'
                ],
                'endpoint_path': '/generate/id-mapping',
                'operation_id': 'generate_id_mapping',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'generate_id_mapping_request_body',
                ],
                'required': [
                    'generate_id_mapping_request_body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'generate_id_mapping_request_body':
                        (GenerateIdMappingRequestBody,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'generate_id_mapping_request_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json',
                    'text/plain'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )


    @staticmethod
    def apply_kwargs_defaults(kwargs, return_http_data_only, async_req):
        kwargs["async_req"] = async_req
        kwargs["_return_http_data_only"] = return_http_data_only
        kwargs["_preload_content"] = kwargs.get("_preload_content", True)
        kwargs["_request_timeout"] = kwargs.get("_request_timeout", None)
        kwargs["_check_input_type"] = kwargs.get("_check_input_type", True)
        kwargs["_check_return_type"] = kwargs.get("_check_return_type", True)
        kwargs["_spec_property_naming"] = kwargs.get("_spec_property_naming", False)
        kwargs["_content_type"] = kwargs.get("_content_type")
        kwargs["_host_index"] = kwargs.get("_host_index")


    def calculate_from_holdings(
        self,
        calculate_from_holdings_request_body,
        **kwargs
    ) -> InlineResponse2003:
        """Calculate risk statistics  # noqa: E501

        Calculate predicted risk statistics for provided holdings using risk model data. Asset symbols and market values/weights are required.  # noqa: E501
        This method makes a synchronous HTTP request. Returns the http data only

        Args:
            calculate_from_holdings_request_body (CalculateFromHoldingsRequestBody):

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            InlineResponse2003
                Response Object
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=False)
        kwargs['calculate_from_holdings_request_body'] = \
            calculate_from_holdings_request_body
        return self.calculate_from_holdings_endpoint.call_with_http_info(**kwargs)

    def calculate_from_holdings_with_http_info(
        self,
        calculate_from_holdings_request_body,
        **kwargs
    ) -> typing.Tuple[InlineResponse2003, int, typing.MutableMapping]:
        """Calculate risk statistics  # noqa: E501

        Calculate predicted risk statistics for provided holdings using risk model data. Asset symbols and market values/weights are required.  # noqa: E501
        This method makes a synchronous HTTP request. Returns http data, http status and headers

        Args:
            calculate_from_holdings_request_body (CalculateFromHoldingsRequestBody):

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            InlineResponse2003
                Response Object
            int
                Http Status Code
            dict
                Dictionary of the response headers
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=False)
        kwargs['calculate_from_holdings_request_body'] = \
            calculate_from_holdings_request_body
        return self.calculate_from_holdings_endpoint.call_with_http_info(**kwargs)

    def calculate_from_holdings_async(
        self,
        calculate_from_holdings_request_body,
        **kwargs
    ) -> "ApplyResult[InlineResponse2003]":
        """Calculate risk statistics  # noqa: E501

        Calculate predicted risk statistics for provided holdings using risk model data. Asset symbols and market values/weights are required.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns the http data, wrapped in ApplyResult

        Args:
            calculate_from_holdings_request_body (CalculateFromHoldingsRequestBody):

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[InlineResponse2003]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=True)
        kwargs['calculate_from_holdings_request_body'] = \
            calculate_from_holdings_request_body
        return self.calculate_from_holdings_endpoint.call_with_http_info(**kwargs)

    def calculate_from_holdings_with_http_info_async(
        self,
        calculate_from_holdings_request_body,
        **kwargs
    ) -> "ApplyResult[typing.Tuple[InlineResponse2003, int, typing.MutableMapping]]":
        """Calculate risk statistics  # noqa: E501

        Calculate predicted risk statistics for provided holdings using risk model data. Asset symbols and market values/weights are required.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns http data, http status and headers, wrapped in ApplyResult

        Args:
            calculate_from_holdings_request_body (CalculateFromHoldingsRequestBody):

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[(InlineResponse2003, int, typing.Dict)]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=True)
        kwargs['calculate_from_holdings_request_body'] = \
            calculate_from_holdings_request_body
        return self.calculate_from_holdings_endpoint.call_with_http_info(**kwargs)


    def generate_id_mapping(
        self,
        generate_id_mapping_request_body,
        **kwargs
    ) -> InlineResponse2004:
        """Generate risk model ID mapping  # noqa: E501

        Resolve all input holdings IDs against a risk model for coverage and provide a mapping to security indices in the model or the reason for exclusion  # noqa: E501
        This method makes a synchronous HTTP request. Returns the http data only

        Args:
            generate_id_mapping_request_body (GenerateIdMappingRequestBody):

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            InlineResponse2004
                Response Object
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=False)
        kwargs['generate_id_mapping_request_body'] = \
            generate_id_mapping_request_body
        return self.generate_id_mapping_endpoint.call_with_http_info(**kwargs)

    def generate_id_mapping_with_http_info(
        self,
        generate_id_mapping_request_body,
        **kwargs
    ) -> typing.Tuple[InlineResponse2004, int, typing.MutableMapping]:
        """Generate risk model ID mapping  # noqa: E501

        Resolve all input holdings IDs against a risk model for coverage and provide a mapping to security indices in the model or the reason for exclusion  # noqa: E501
        This method makes a synchronous HTTP request. Returns http data, http status and headers

        Args:
            generate_id_mapping_request_body (GenerateIdMappingRequestBody):

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            InlineResponse2004
                Response Object
            int
                Http Status Code
            dict
                Dictionary of the response headers
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=False)
        kwargs['generate_id_mapping_request_body'] = \
            generate_id_mapping_request_body
        return self.generate_id_mapping_endpoint.call_with_http_info(**kwargs)

    def generate_id_mapping_async(
        self,
        generate_id_mapping_request_body,
        **kwargs
    ) -> "ApplyResult[InlineResponse2004]":
        """Generate risk model ID mapping  # noqa: E501

        Resolve all input holdings IDs against a risk model for coverage and provide a mapping to security indices in the model or the reason for exclusion  # noqa: E501
        This method makes a asynchronous HTTP request. Returns the http data, wrapped in ApplyResult

        Args:
            generate_id_mapping_request_body (GenerateIdMappingRequestBody):

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[InlineResponse2004]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=True)
        kwargs['generate_id_mapping_request_body'] = \
            generate_id_mapping_request_body
        return self.generate_id_mapping_endpoint.call_with_http_info(**kwargs)

    def generate_id_mapping_with_http_info_async(
        self,
        generate_id_mapping_request_body,
        **kwargs
    ) -> "ApplyResult[typing.Tuple[InlineResponse2004, int, typing.MutableMapping]]":
        """Generate risk model ID mapping  # noqa: E501

        Resolve all input holdings IDs against a risk model for coverage and provide a mapping to security indices in the model or the reason for exclusion  # noqa: E501
        This method makes a asynchronous HTTP request. Returns http data, http status and headers, wrapped in ApplyResult

        Args:
            generate_id_mapping_request_body (GenerateIdMappingRequestBody):

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[(InlineResponse2004, int, typing.Dict)]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=True)
        kwargs['generate_id_mapping_request_body'] = \
            generate_id_mapping_request_body
        return self.generate_id_mapping_endpoint.call_with_http_info(**kwargs)





"""
    Open:Risk API

    Service to calculate parametric linear risk statistics and generate risk model asset identifier mappings.  # noqa: E501

    The version of the OpenAPI document: 1.26.0
    Contact: api@factset.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401
from multiprocessing.pool import ApplyResult
import typing

from fds.sdk.OpenRisk.api_client import ApiClient, Endpoint as _Endpoint
from fds.sdk.OpenRisk.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from fds.sdk.OpenRisk.exceptions import ApiException
from fds.sdk.OpenRisk.model.error_response import ErrorResponse
from fds.sdk.OpenRisk.model.inline_response200 import InlineResponse200
from fds.sdk.OpenRisk.model.inline_response2001 import InlineResponse2001
from fds.sdk.OpenRisk.model.inline_response2002 import InlineResponse2002
from fds.sdk.OpenRisk.model.inline_response403 import InlineResponse403
from fds.sdk.OpenRisk.model.inline_response404 import InlineResponse404
from fds.sdk.OpenRisk.model.risk_model_code import RiskModelCode
from fds.sdk.OpenRisk.model.supported_stats import SupportedStats
from fds.sdk.OpenRisk.model.supported_stats_names_only import SupportedStatsNamesOnly





class AboutApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self.health_status_endpoint = _Endpoint(
            settings={
                'response_type': (
                  { 200: (InlineResponse2002,), 401: (str,), 403: (InlineResponse403,), 404: (InlineResponse404,), 500: (InlineResponse403,),  },
                  None
                ),
                'auth': [
                    'FactSetApiKey',
                    'FactSetOAuth2'
                ],
                'endpoint_path': '/health',
                'operation_id': 'health_status',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json',
                    'text/plain'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

        self.list_risk_models_endpoint = _Endpoint(
            settings={
                'response_type': (
                  { 200: (InlineResponse200,), 401: (str,), 404: (ErrorResponse,), 500: (ErrorResponse,),  },
                  None
                ),
                'auth': [
                    'FactSetApiKey',
                    'FactSetOAuth2'
                ],
                'endpoint_path': '/riskmodels',
                'operation_id': 'list_risk_models',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json',
                    'text/plain'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

        self.risk_model_metadata_endpoint = _Endpoint(
            settings={
                'response_type': (
                  { 200: (InlineResponse2001,), 401: (str,), 404: (ErrorResponse,), 500: (ErrorResponse,),  },
                  None
                ),
                'auth': [
                    'FactSetApiKey',
                    'FactSetOAuth2'
                ],
                'endpoint_path': '/riskmodels/{modelCode}',
                'operation_id': 'risk_model_metadata',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'model_code',
                ],
                'required': [
                    'model_code',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'model_code':
                        (RiskModelCode,),
                },
                'attribute_map': {
                    'model_code': 'modelCode',
                },
                'location_map': {
                    'model_code': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json',
                    'text/plain'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

        self.stats_endpoint = _Endpoint(
            settings={
                'response_type': (
                  { 200: (SupportedStats,), 401: (str,), 404: (ErrorResponse,), 500: (ErrorResponse,),  },
                  None
                ),
                'auth': [
                    'FactSetApiKey',
                    'FactSetOAuth2'
                ],
                'endpoint_path': '/stats',
                'operation_id': 'stats',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json',
                    'text/plain'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

        self.stats_names_only_endpoint = _Endpoint(
            settings={
                'response_type': (
                  { 200: (SupportedStatsNamesOnly,), 401: (str,), 404: (ErrorResponse,), 500: (ErrorResponse,),  },
                  None
                ),
                'auth': [
                    'FactSetApiKey',
                    'FactSetOAuth2'
                ],
                'endpoint_path': '/stats-names-only',
                'operation_id': 'stats_names_only',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json',
                    'text/plain'
                ],
                'content_type': [],
            },
            api_client=api_client
        )


    @staticmethod
    def apply_kwargs_defaults(kwargs, return_http_data_only, async_req):
        kwargs["async_req"] = async_req
        kwargs["_return_http_data_only"] = return_http_data_only
        kwargs["_preload_content"] = kwargs.get("_preload_content", True)
        kwargs["_request_timeout"] = kwargs.get("_request_timeout", None)
        kwargs["_check_input_type"] = kwargs.get("_check_input_type", True)
        kwargs["_check_return_type"] = kwargs.get("_check_return_type", True)
        kwargs["_spec_property_naming"] = kwargs.get("_spec_property_naming", False)
        kwargs["_content_type"] = kwargs.get("_content_type")
        kwargs["_host_index"] = kwargs.get("_host_index")


    def health_status(
        self,
        **kwargs
    ) -> InlineResponse2002:
        """Get health of service  # noqa: E501

        Health status of the service  # noqa: E501
        This method makes a synchronous HTTP request. Returns the http data only


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            InlineResponse2002
                Response Object
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=False)
        return self.health_status_endpoint.call_with_http_info(**kwargs)

    def health_status_with_http_info(
        self,
        **kwargs
    ) -> typing.Tuple[InlineResponse2002, int, typing.MutableMapping]:
        """Get health of service  # noqa: E501

        Health status of the service  # noqa: E501
        This method makes a synchronous HTTP request. Returns http data, http status and headers


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            InlineResponse2002
                Response Object
            int
                Http Status Code
            dict
                Dictionary of the response headers
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=False)
        return self.health_status_endpoint.call_with_http_info(**kwargs)

    def health_status_async(
        self,
        **kwargs
    ) -> "ApplyResult[InlineResponse2002]":
        """Get health of service  # noqa: E501

        Health status of the service  # noqa: E501
        This method makes a asynchronous HTTP request. Returns the http data, wrapped in ApplyResult


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[InlineResponse2002]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=True)
        return self.health_status_endpoint.call_with_http_info(**kwargs)

    def health_status_with_http_info_async(
        self,
        **kwargs
    ) -> "ApplyResult[typing.Tuple[InlineResponse2002, int, typing.MutableMapping]]":
        """Get health of service  # noqa: E501

        Health status of the service  # noqa: E501
        This method makes a asynchronous HTTP request. Returns http data, http status and headers, wrapped in ApplyResult


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[(InlineResponse2002, int, typing.Dict)]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=True)
        return self.health_status_endpoint.call_with_http_info(**kwargs)


    def list_risk_models(
        self,
        **kwargs
    ) -> InlineResponse200:
        """Get available risk models  # noqa: E501

        Get the list of available risk models, including their respective model codes required for use with other routes.  # noqa: E501
        This method makes a synchronous HTTP request. Returns the http data only


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            InlineResponse200
                Response Object
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=False)
        return self.list_risk_models_endpoint.call_with_http_info(**kwargs)

    def list_risk_models_with_http_info(
        self,
        **kwargs
    ) -> typing.Tuple[InlineResponse200, int, typing.MutableMapping]:
        """Get available risk models  # noqa: E501

        Get the list of available risk models, including their respective model codes required for use with other routes.  # noqa: E501
        This method makes a synchronous HTTP request. Returns http data, http status and headers


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            InlineResponse200
                Response Object
            int
                Http Status Code
            dict
                Dictionary of the response headers
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=False)
        return self.list_risk_models_endpoint.call_with_http_info(**kwargs)

    def list_risk_models_async(
        self,
        **kwargs
    ) -> "ApplyResult[InlineResponse200]":
        """Get available risk models  # noqa: E501

        Get the list of available risk models, including their respective model codes required for use with other routes.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns the http data, wrapped in ApplyResult


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[InlineResponse200]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=True)
        return self.list_risk_models_endpoint.call_with_http_info(**kwargs)

    def list_risk_models_with_http_info_async(
        self,
        **kwargs
    ) -> "ApplyResult[typing.Tuple[InlineResponse200, int, typing.MutableMapping]]":
        """Get available risk models  # noqa: E501

        Get the list of available risk models, including their respective model codes required for use with other routes.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns http data, http status and headers, wrapped in ApplyResult


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[(InlineResponse200, int, typing.Dict)]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=True)
        return self.list_risk_models_endpoint.call_with_http_info(**kwargs)


    def risk_model_metadata(
        self,
        model_code,
        **kwargs
    ) -> InlineResponse2001:
        """Get risk model details  # noqa: E501

        Get the metadata of the risk model for the corresponding modelCode. modelCode can be obtained via '/linear/{version}/riskmodels/' route.  # noqa: E501
        This method makes a synchronous HTTP request. Returns the http data only

        Args:
            model_code (RiskModelCode): Model code

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            InlineResponse2001
                Response Object
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=False)
        kwargs['model_code'] = \
            model_code
        return self.risk_model_metadata_endpoint.call_with_http_info(**kwargs)

    def risk_model_metadata_with_http_info(
        self,
        model_code,
        **kwargs
    ) -> typing.Tuple[InlineResponse2001, int, typing.MutableMapping]:
        """Get risk model details  # noqa: E501

        Get the metadata of the risk model for the corresponding modelCode. modelCode can be obtained via '/linear/{version}/riskmodels/' route.  # noqa: E501
        This method makes a synchronous HTTP request. Returns http data, http status and headers

        Args:
            model_code (RiskModelCode): Model code

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            InlineResponse2001
                Response Object
            int
                Http Status Code
            dict
                Dictionary of the response headers
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=False)
        kwargs['model_code'] = \
            model_code
        return self.risk_model_metadata_endpoint.call_with_http_info(**kwargs)

    def risk_model_metadata_async(
        self,
        model_code,
        **kwargs
    ) -> "ApplyResult[InlineResponse2001]":
        """Get risk model details  # noqa: E501

        Get the metadata of the risk model for the corresponding modelCode. modelCode can be obtained via '/linear/{version}/riskmodels/' route.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns the http data, wrapped in ApplyResult

        Args:
            model_code (RiskModelCode): Model code

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[InlineResponse2001]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=True)
        kwargs['model_code'] = \
            model_code
        return self.risk_model_metadata_endpoint.call_with_http_info(**kwargs)

    def risk_model_metadata_with_http_info_async(
        self,
        model_code,
        **kwargs
    ) -> "ApplyResult[typing.Tuple[InlineResponse2001, int, typing.MutableMapping]]":
        """Get risk model details  # noqa: E501

        Get the metadata of the risk model for the corresponding modelCode. modelCode can be obtained via '/linear/{version}/riskmodels/' route.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns http data, http status and headers, wrapped in ApplyResult

        Args:
            model_code (RiskModelCode): Model code

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[(InlineResponse2001, int, typing.Dict)]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=True)
        kwargs['model_code'] = \
            model_code
        return self.risk_model_metadata_endpoint.call_with_http_info(**kwargs)


    def stats(
        self,
        **kwargs
    ) -> SupportedStats:
        """Get available risk statistics details  # noqa: E501

        All base risk statistic names and their respective support and/or requirement for certain name-settings statistics options (such as: correlated specific risk, covariance isolation method, etc.), available levels, and security group calculation methodology. When 'securityGroupMethod' is 'statSpecific', please refer to statistics documentation service for more information.  # noqa: E501
        This method makes a synchronous HTTP request. Returns the http data only


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            SupportedStats
                Response Object
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=False)
        return self.stats_endpoint.call_with_http_info(**kwargs)

    def stats_with_http_info(
        self,
        **kwargs
    ) -> typing.Tuple[SupportedStats, int, typing.MutableMapping]:
        """Get available risk statistics details  # noqa: E501

        All base risk statistic names and their respective support and/or requirement for certain name-settings statistics options (such as: correlated specific risk, covariance isolation method, etc.), available levels, and security group calculation methodology. When 'securityGroupMethod' is 'statSpecific', please refer to statistics documentation service for more information.  # noqa: E501
        This method makes a synchronous HTTP request. Returns http data, http status and headers


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            SupportedStats
                Response Object
            int
                Http Status Code
            dict
                Dictionary of the response headers
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=False)
        return self.stats_endpoint.call_with_http_info(**kwargs)

    def stats_async(
        self,
        **kwargs
    ) -> "ApplyResult[SupportedStats]":
        """Get available risk statistics details  # noqa: E501

        All base risk statistic names and their respective support and/or requirement for certain name-settings statistics options (such as: correlated specific risk, covariance isolation method, etc.), available levels, and security group calculation methodology. When 'securityGroupMethod' is 'statSpecific', please refer to statistics documentation service for more information.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns the http data, wrapped in ApplyResult


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[SupportedStats]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=True)
        return self.stats_endpoint.call_with_http_info(**kwargs)

    def stats_with_http_info_async(
        self,
        **kwargs
    ) -> "ApplyResult[typing.Tuple[SupportedStats, int, typing.MutableMapping]]":
        """Get available risk statistics details  # noqa: E501

        All base risk statistic names and their respective support and/or requirement for certain name-settings statistics options (such as: correlated specific risk, covariance isolation method, etc.), available levels, and security group calculation methodology. When 'securityGroupMethod' is 'statSpecific', please refer to statistics documentation service for more information.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns http data, http status and headers, wrapped in ApplyResult


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[(SupportedStats, int, typing.Dict)]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=True)
        return self.stats_endpoint.call_with_http_info(**kwargs)


    def stats_names_only(
        self,
        **kwargs
    ) -> SupportedStatsNamesOnly:
        """Get available risk statistics names  # noqa: E501

        All available risk statistic names including statistics names containing risk statistics options such as CSR (correlated specific risk)  # noqa: E501
        This method makes a synchronous HTTP request. Returns the http data only


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            SupportedStatsNamesOnly
                Response Object
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=False)
        return self.stats_names_only_endpoint.call_with_http_info(**kwargs)

    def stats_names_only_with_http_info(
        self,
        **kwargs
    ) -> typing.Tuple[SupportedStatsNamesOnly, int, typing.MutableMapping]:
        """Get available risk statistics names  # noqa: E501

        All available risk statistic names including statistics names containing risk statistics options such as CSR (correlated specific risk)  # noqa: E501
        This method makes a synchronous HTTP request. Returns http data, http status and headers


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            SupportedStatsNamesOnly
                Response Object
            int
                Http Status Code
            dict
                Dictionary of the response headers
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=False)
        return self.stats_names_only_endpoint.call_with_http_info(**kwargs)

    def stats_names_only_async(
        self,
        **kwargs
    ) -> "ApplyResult[SupportedStatsNamesOnly]":
        """Get available risk statistics names  # noqa: E501

        All available risk statistic names including statistics names containing risk statistics options such as CSR (correlated specific risk)  # noqa: E501
        This method makes a asynchronous HTTP request. Returns the http data, wrapped in ApplyResult


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[SupportedStatsNamesOnly]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=True)
        return self.stats_names_only_endpoint.call_with_http_info(**kwargs)

    def stats_names_only_with_http_info_async(
        self,
        **kwargs
    ) -> "ApplyResult[typing.Tuple[SupportedStatsNamesOnly, int, typing.MutableMapping]]":
        """Get available risk statistics names  # noqa: E501

        All available risk statistic names including statistics names containing risk statistics options such as CSR (correlated specific risk)  # noqa: E501
        This method makes a asynchronous HTTP request. Returns http data, http status and headers, wrapped in ApplyResult


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[(SupportedStatsNamesOnly, int, typing.Dict)]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=True)
        return self.stats_names_only_endpoint.call_with_http_info(**kwargs)





# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from fds.sdk.OpenRisk.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from fds.sdk.OpenRisk.model.additional_calculation_inputs import AdditionalCalculationInputs
from fds.sdk.OpenRisk.model.additional_calculation_inputs_market_excess import AdditionalCalculationInputsMarketExcess
from fds.sdk.OpenRisk.model.asset_types import AssetTypes
from fds.sdk.OpenRisk.model.calculate_from_holdings_request_body import CalculateFromHoldingsRequestBody
from fds.sdk.OpenRisk.model.calculate_from_holdings_request_data import CalculateFromHoldingsRequestData
from fds.sdk.OpenRisk.model.calendar_code import CalendarCode
from fds.sdk.OpenRisk.model.composite_asset_definitions import CompositeAssetDefinitions
from fds.sdk.OpenRisk.model.covariance_date_format_convention import CovarianceDateFormatConvention
from fds.sdk.OpenRisk.model.currency_iso_code import CurrencyIsoCode
from fds.sdk.OpenRisk.model.error_item import ErrorItem
from fds.sdk.OpenRisk.model.error_response import ErrorResponse
from fds.sdk.OpenRisk.model.exposure_date_format_convention import ExposureDateFormatConvention
from fds.sdk.OpenRisk.model.factor_group import FactorGroup
from fds.sdk.OpenRisk.model.factor_group_nodes import FactorGroupNodes
from fds.sdk.OpenRisk.model.factors_visible import FactorsVisible
from fds.sdk.OpenRisk.model.generate_id_mapping_request_body import GenerateIdMappingRequestBody
from fds.sdk.OpenRisk.model.generate_id_mapping_request_data import GenerateIdMappingRequestData
from fds.sdk.OpenRisk.model.groups_labels import GroupsLabels
from fds.sdk.OpenRisk.model.holding import Holding
from fds.sdk.OpenRisk.model.holding_all_of import HoldingAllOf
from fds.sdk.OpenRisk.model.holdings import Holdings
from fds.sdk.OpenRisk.model.ids_and_market_values import IDsAndMarketValues
from fds.sdk.OpenRisk.model.inline_response200 import InlineResponse200
from fds.sdk.OpenRisk.model.inline_response2001 import InlineResponse2001
from fds.sdk.OpenRisk.model.inline_response2001_data import InlineResponse2001Data
from fds.sdk.OpenRisk.model.inline_response2002 import InlineResponse2002
from fds.sdk.OpenRisk.model.inline_response2003 import InlineResponse2003
from fds.sdk.OpenRisk.model.inline_response2004 import InlineResponse2004
from fds.sdk.OpenRisk.model.inline_response403 import InlineResponse403
from fds.sdk.OpenRisk.model.inline_response404 import InlineResponse404
from fds.sdk.OpenRisk.model.input_date import InputDate
from fds.sdk.OpenRisk.model.input_to_result_security_index_mapping import InputToResultSecurityIndexMapping
from fds.sdk.OpenRisk.model.labels import Labels
from fds.sdk.OpenRisk.model.labels_factor import LabelsFactor
from fds.sdk.OpenRisk.model.labels_security import LabelsSecurity
from fds.sdk.OpenRisk.model.lagging_dates import LaggingDates
from fds.sdk.OpenRisk.model.mapped_security_info import MappedSecurityInfo
from fds.sdk.OpenRisk.model.remove_currency_risk import RemoveCurrencyRisk
from fds.sdk.OpenRisk.model.remove_currency_risk_ids import RemoveCurrencyRiskIds
from fds.sdk.OpenRisk.model.requires_factor_returns import RequiresFactorReturns
from fds.sdk.OpenRisk.model.resolved_dates import ResolvedDates
from fds.sdk.OpenRisk.model.result_to_input_security_index_mapping import ResultToInputSecurityIndexMapping
from fds.sdk.OpenRisk.model.risk_exclusion_info import RiskExclusionInfo
from fds.sdk.OpenRisk.model.risk_exclusion_info_exclusion_info import RiskExclusionInfoExclusionInfo
from fds.sdk.OpenRisk.model.risk_mapping_entry import RiskMappingEntry
from fds.sdk.OpenRisk.model.risk_model_append_data import RiskModelAppendData
from fds.sdk.OpenRisk.model.risk_model_append_data_row import RiskModelAppendDataRow
from fds.sdk.OpenRisk.model.risk_model_append_data_value import RiskModelAppendDataValue
from fds.sdk.OpenRisk.model.risk_model_append_field_type import RiskModelAppendFieldType
from fds.sdk.OpenRisk.model.risk_model_code import RiskModelCode
from fds.sdk.OpenRisk.model.risk_model_factor import RiskModelFactor
from fds.sdk.OpenRisk.model.risk_model_factor_details import RiskModelFactorDetails
from fds.sdk.OpenRisk.model.risk_model_summary import RiskModelSummary
from fds.sdk.OpenRisk.model.security_group import SecurityGroup
from fds.sdk.OpenRisk.model.security_index_mapping import SecurityIndexMapping
from fds.sdk.OpenRisk.model.security_only_labels import SecurityOnlyLabels
from fds.sdk.OpenRisk.model.security_only_labels_security import SecurityOnlyLabelsSecurity
from fds.sdk.OpenRisk.model.security_only_success_response_meta import SecurityOnlySuccessResponseMeta
from fds.sdk.OpenRisk.model.stat import Stat
from fds.sdk.OpenRisk.model.stat_calculation_level import StatCalculationLevel
from fds.sdk.OpenRisk.model.stat_calculation_settings import StatCalculationSettings
from fds.sdk.OpenRisk.model.stat_result import StatResult
from fds.sdk.OpenRisk.model.stat_result_value import StatResultValue
from fds.sdk.OpenRisk.model.stat_result_value_dense_matrix import StatResultValueDenseMatrix
from fds.sdk.OpenRisk.model.stat_result_value_sparse_matrix import StatResultValueSparseMatrix
from fds.sdk.OpenRisk.model.stat_result_value_vector import StatResultValueVector
from fds.sdk.OpenRisk.model.stats import Stats
from fds.sdk.OpenRisk.model.stats_results import StatsResults
from fds.sdk.OpenRisk.model.string_date import StringDate
from fds.sdk.OpenRisk.model.success_response_meta import SuccessResponseMeta
from fds.sdk.OpenRisk.model.supported_stat_details import SupportedStatDetails
from fds.sdk.OpenRisk.model.supported_stat_details_security_group_method import SupportedStatDetailsSecurityGroupMethod
from fds.sdk.OpenRisk.model.supported_stats import SupportedStats
from fds.sdk.OpenRisk.model.supported_stats_names_only import SupportedStatsNamesOnly
from fds.sdk.OpenRisk.model.underlying_ids import UnderlyingIds
from fds.sdk.OpenRisk.model.warning_item import WarningItem
from fds.sdk.OpenRisk.model.warnings import Warnings
